<p align="center"><img src="docs/orbitize_logo_500.png" alt="orbitize!" width="100"/></p>

# orbitize!

Orbit-fitting for directly imaged objects. For installation instructions, tutorials, and detailed documentation, start [here](http://orbitize.readthedocs.io/en/latest/).

[![Build Status](https://travis-ci.org/sblunt/orbitize.svg?branch=master)](https://travis-ci.org/sblunt/orbitize/)
[![Coverage Status](https://coveralls.io/repos/github/sblunt/orbitize/badge.svg?branch=master&service=github)](https://coveralls.io/github/sblunt/orbitize?branch=master&service=github)
[![Documentation Status](https://readthedocs.org/projects/orbitize/badge/?version=latest)](http://orbitize.readthedocs.io/en/latest/?badge=latest)
[![Requirements Status](https://requires.io/github/sblunt/orbitize/requirements.svg?branch=main)](https://requires.io/github/sblunt/orbitize/requirements/?branch=main)
[![PyPI version](https://badge.fury.io/py/orbitize.svg)](https://badge.fury.io/py/orbitize)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3337378.svg)](https://zenodo.org/record/3337378#.XUHT3ZNKjUJ)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
